# Manager Data
# 8명의 C-Level 매니저 데이터

from .pm import PM_DATA
from .cto import CTO_DATA
from .qa import QA_DATA
from .cdo import CDO_DATA
from .cmo import CMO_DATA
from .cfo import CFO_DATA
from .cso import CSO_DATA
from .error import ERROR_DATA

MANAGERS = {
    "PM": PM_DATA,
    "CTO": CTO_DATA,
    "QA": QA_DATA,
    "CDO": CDO_DATA,
    "CMO": CMO_DATA,
    "CFO": CFO_DATA,
    "CSO": CSO_DATA,
    "ERROR": ERROR_DATA,
}

# 컨텍스트 기반 매니저 그룹핑
CONTEXT_GROUPS = {'auth': ['CSO', 'CTO', 'QA', 'ERROR'], 'payment': ['CFO', 'CSO', 'CTO', 'QA', 'ERROR'], 'api': ['CTO', 'QA', 'CSO', 'ERROR'], 'ui': ['CDO', 'PM', 'QA'], 'feature': ['PM', 'CTO', 'QA'], 'security': ['CSO', 'CTO', 'QA', 'ERROR'], 'performance': ['CTO', 'QA', 'CFO'], 'launch': ['CMO', 'PM', 'CFO', 'QA'], 'error': ['ERROR', 'CTO', 'QA'], 'design': ['CDO', 'PM', 'CMO'], 'database': ['CTO', 'CSO', 'QA', 'ERROR']}

# Phase 우선순위 (정렬용)
PHASE_ORDER = {'준비': 1, '설계': 2, '구현': 3, '검증': 4}

__all__ = ["MANAGERS", "CONTEXT_GROUPS", "PHASE_ORDER"]
